Module beamlit.models.api_key
=============================

Classes
-------

`ApiKey(created_at: beamlit.types.Unset | str = <beamlit.types.Unset object>, updated_at: beamlit.types.Unset | str = <beamlit.types.Unset object>, created_by: beamlit.types.Unset | str = <beamlit.types.Unset object>, updated_by: beamlit.types.Unset | str = <beamlit.types.Unset object>, api_key: beamlit.types.Unset | str = <beamlit.types.Unset object>, expires_in: beamlit.types.Unset | str = <beamlit.types.Unset object>, id: beamlit.types.Unset | str = <beamlit.types.Unset object>, name: beamlit.types.Unset | str = <beamlit.types.Unset object>, sub: beamlit.types.Unset | str = <beamlit.types.Unset object>, sub_type: beamlit.types.Unset | str = <beamlit.types.Unset object>)`
:   Long-lived API key for accessing Beamlit
    
    Attributes:
        created_at (Union[Unset, str]): The date and time when the resource was created
        updated_at (Union[Unset, str]): The date and time when the resource was updated
        created_by (Union[Unset, str]): The user or service account who created the resource
        updated_by (Union[Unset, str]): The user or service account who updated the resource
        api_key (Union[Unset, str]): Api key
        expires_in (Union[Unset, str]): Duration until expiration (in seconds)
        id (Union[Unset, str]): Api key id, to retrieve it from the API
        name (Union[Unset, str]): Name for the API key
        sub (Union[Unset, str]): User subject identifier
        sub_type (Union[Unset, str]): Subject type
    
    Method generated by attrs for class ApiKey.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `api_key: beamlit.types.Unset | str`
    :

    `created_at: beamlit.types.Unset | str`
    :

    `created_by: beamlit.types.Unset | str`
    :

    `expires_in: beamlit.types.Unset | str`
    :

    `id: beamlit.types.Unset | str`
    :

    `name: beamlit.types.Unset | str`
    :

    `sub: beamlit.types.Unset | str`
    :

    `sub_type: beamlit.types.Unset | str`
    :

    `updated_at: beamlit.types.Unset | str`
    :

    `updated_by: beamlit.types.Unset | str`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :